UnitChain

Trait UnitChain 

pub trait UnitChain<'c, S>
where S: Socket,
{ // Required method fn list<'__proxy_params>( self, name: Option<&'__proxy_params str>, ) -> Result<Chain<'c, S>>; }
Extension trait for adding proxy calls to any chain.

This trait provides methods to add proxy calls to a chain of method calls.

Required Methods

fn list<'__proxy_params>( self, name: Option<&'__proxy_params str>, ) -> Result<Chain<'c, S>>

Add a #method_name call to this chain.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'c, S> UnitChain<'c, S> for Chain<'c, S>
where S: Socket,

Source

fn list<'__proxy_params>( self, name: Option<&'__proxy_params str>, ) -> Result<Chain<'c, S>>

Implementors